@@ -13,6 +13,6 @@ from pysus.utilities.readdbc import read_dbc
 
 class TestReadDbc(unittest.TestCase):
     def test_read_dbc(self):
-        df = read_dbc(b'test_data/sids.dbc')
+        df = read_dbc(b"test_data/sids.dbc")
         self.assertIsInstance(df, pd.DataFrame)
         self.assertGreater(df.size, 0)
